# TODO

[X] tigr81 commands refactoring
[X] scaffold react
    [X] add linter formatter ecc script from templates
    [] input: framework - prime react or mui
    
[] MUI template
[X] prime react template
[X] fastapi better
    OK -> add __main__
    OK -> pydantic settings
    OK -> ruff and dev deps
    - script/commands to run in project lifecycle
    fastapi auth provider: api key, oauth,..
    config modules pydantic
    model config commons config camel case
    [] lifespan
    [] logging as json

[] Check monorepo how work now...
[] fastapi: Dockerfile
[X] python templates: ruff + code linting setup
[] typer cli template
[] chatbot template RAG opensource
[] monorepo: add just dependency
[] monorepo: delete dependencies already present when add
[] deploy 1.1.0 version
